@@ -462,10 +462,14 @@ get_newline_type (GtkTextIter *end)
 			res = GTK_SOURCE_NEWLINE_TYPE_CR;
 		}
 	}
-	else
+	else if (c)
 	{
 		res = GTK_SOURCE_NEWLINE_TYPE_LF;
 	}
+	else
+	{
+		res = GTK_SOURCE_NEWLINE_TYPE_DEFAULT;
+	}
 
 	return res;
 }
@@ -705,7 +709,8 @@ validate_and_insert (GtkSourceBufferOutputStream *stream,
 
 			apply_error_tag (stream);
 
-			if ((nvalid != len || !owned) && buffer[nvalid] != '\0')
+			if (!owned ||
+			    (nvalid != len && buffer[nvalid] != '\0'))
 			{
 				/* make sure the buffer is always properly null
 				 * terminated. This is needed, at least for now,
