@@ -50,12 +50,6 @@
  * function names, etc. To add a provider, call
  * [method@Completion.add_provider].
  *
- * When several providers match, they are all shown in the completion
- * window, but one can switch between providers: see the
- * #GtkSourceCompletion::move-page signal. It is also possible to
- * activate the first proposals with key bindings, see the
- * #GtkSourceCompletion:accelerators property.
- *
  * The [iface@CompletionProposal] interface represents a proposal.
  *
  * If a proposal contains extra information (see
@@ -149,7 +143,7 @@ struct _GtkSourceCompletion
 	guint page_size;
 
 	/* Handler for gtk_widget_add_tick_callback() to do delayed calls to
-	 * gtk_widget_hide() (so that we don't potentially flap between
+	 * gtk_widget_set_visible(FALSE) (so that we don't potentially flap between
 	 * hide/show while typing.
 	 */
 	guint hide_tick_handler;
@@ -215,7 +209,7 @@ display_show (GtkSourceCompletion *self)
 
 	if (gtk_widget_get_mapped (GTK_WIDGET (self->view)))
 	{
-		gtk_widget_show (GTK_WIDGET (_gtk_source_completion_get_display (self)));
+		gtk_widget_set_visible (GTK_WIDGET (_gtk_source_completion_get_display (self)), TRUE);
 	}
 }
 
@@ -234,7 +228,7 @@ display_hide_cb (GtkWidget     *widget,
 
 	if (self->display != NULL)
 	{
-		gtk_widget_hide (GTK_WIDGET (self->display));
+		gtk_widget_set_visible (GTK_WIDGET (self->display), FALSE);
 	}
 
 	return G_SOURCE_REMOVE;
@@ -428,7 +422,7 @@ gtk_source_completion_cancel (GtkSourceCompletion *self)
 		if (self->display != NULL)
 		{
 			_gtk_source_completion_list_set_context (self->display, NULL);
-			gtk_widget_hide (GTK_WIDGET (self->display));
+			gtk_widget_set_visible (GTK_WIDGET (self->display), FALSE);
 		}
 	}
 }
@@ -634,7 +628,7 @@ gtk_source_completion_real_hide (GtkSourceCompletion *self)
 
 	if (self->display != NULL)
 	{
-		gtk_widget_hide (GTK_WIDGET (self->display));
+		gtk_widget_set_visible (GTK_WIDGET (self->display), FALSE);
 	}
 }
 
@@ -647,14 +641,14 @@ gtk_source_completion_real_show (GtkSourceCompletion *self)
 
 	display = _gtk_source_completion_get_display (self);
 
-	if (self->context == NULL)
-	{
-		gtk_source_completion_start (self, GTK_SOURCE_COMPLETION_ACTIVATION_USER_REQUESTED, FALSE);
-	}
-	else
-	{
-		gtk_source_completion_update (self, GTK_SOURCE_COMPLETION_ACTIVATION_USER_REQUESTED, FALSE);
-	}
+	/* If the user is requesting completion manually, we should throw away
+	 * our previous results and attempt completion over. Otherwise, providers
+	 * which bailed because they were in _INTERACTIVE_ mode will not be
+	 * requeried for updated results.
+	 */
+	g_clear_object (&self->context);
+
+	gtk_source_completion_start (self, GTK_SOURCE_COMPLETION_ACTIVATION_USER_REQUESTED, FALSE);
 
 	_gtk_source_completion_list_set_context (display, self->context);
 
