@@ -420,6 +420,7 @@ static void
 gtk_source_gutter_dispose (GObject *object)
 {
 	GtkSourceGutter *gutter = (GtkSourceGutter *)object;
+	GtkWidget *child;
 
 	g_clear_pointer (&gutter->target_binding, g_binding_unbind);
 
@@ -429,6 +430,11 @@ gtk_source_gutter_dispose (GObject *object)
 		g_clear_object (&gutter->signals);
 	}
 
+	while ((child = gtk_widget_get_first_child (GTK_WIDGET (gutter))))
+	{
+		gtk_widget_unparent (child);
+	}
+
 	G_OBJECT_CLASS (gtk_source_gutter_parent_class)->dispose (object);
 }
 
@@ -818,9 +824,12 @@ gtk_source_gutter_snapshot (GtkWidget   *widget,
 		}
 	}
 
-	/* Draw the current-line highlight if necessary */
+	/* Draw the current-line highlight if necessary. Keep this in sync
+         * with gtk_source_view_paint_current_line_highlight().
+         */
 	if (gtk_source_view_get_highlight_current_line (gutter->view) &&
-	    !gtk_text_buffer_get_selection_bounds (buffer, &cur, &sel))
+	    (!gtk_text_buffer_get_selection_bounds (buffer, &cur, &sel) ||
+             gtk_text_iter_get_line (&cur) == gtk_text_iter_get_line (&sel)))
 	{
 		GtkRoot *root;
 		GdkRGBA highlight;
@@ -836,10 +845,10 @@ gtk_source_gutter_snapshot (GtkWidget   *widget,
 		    gtk_window_is_active (GTK_WINDOW (root)))
 		{
 			int width = gtk_widget_get_width (widget);
-			int height;
-			int y;
+			double height;
+			double y;
 
-			gtk_source_gutter_lines_get_line_yrange (gutter->lines,
+			gtk_source_gutter_lines_get_line_extent (gutter->lines,
 			                                         cursor_line,
 			                                         GTK_SOURCE_GUTTER_RENDERER_ALIGNMENT_MODE_CELL,
 			                                         &y,
