@@ -40,13 +40,13 @@
 
 struct _GtkSourceGutterLines
 {
-	GObject       parent_instance;
-	GtkTextView  *view;
-	GArray       *lines;
-	GdkRectangle  visible_rect;
-	guint         first;
-	guint         last;
-	guint         cursor_line;
+	GObject           parent_instance;
+	GtkTextView      *view;
+	GArray           *lines;
+	double            visible_offset;
+	guint             first;
+	guint             last;
+	guint             cursor_line;
 };
 
 typedef struct
@@ -114,9 +114,12 @@ _gtk_source_gutter_lines_new (GtkTextView       *text_view,
 	GtkTextBuffer *buffer;
 	GtkTextMark *mark;
 	GtkTextIter iter;
+	GtkTextIter sel_begin, sel_end;
 	gboolean single_line;
 	guint cursor_line;
 	guint i;
+	int first_selected = -1;
+	int last_selected = -1;
 
 	g_return_val_if_fail (GTK_IS_TEXT_VIEW (text_view), NULL);
 	g_return_val_if_fail (begin != NULL, NULL);
@@ -128,6 +131,13 @@ _gtk_source_gutter_lines_new (GtkTextView       *text_view,
 	g_return_val_if_fail (gtk_text_iter_get_buffer (begin) == buffer, NULL);
 	g_return_val_if_fail (gtk_text_iter_get_buffer (end) == buffer, NULL);
 
+	if (gtk_text_buffer_get_selection_bounds (buffer, &sel_begin, &sel_end))
+	{
+		gtk_text_iter_order (&sel_begin, &sel_end);
+		first_selected = gtk_text_iter_get_line (&sel_begin);
+		last_selected = gtk_text_iter_get_line (&sel_end);
+	}
+
 	if (gtk_text_iter_compare (begin, end) > 0)
 	{
 		const GtkTextIter *tmp = begin;
@@ -146,7 +156,8 @@ _gtk_source_gutter_lines_new (GtkTextView       *text_view,
 	                                  sizeof (LineInfo),
 	                                  lines->last - lines->first + 1);
 	g_array_set_clear_func (lines->lines, clear_line_info);
-	gtk_text_view_get_visible_rect (text_view, &lines->visible_rect);
+
+	gtk_text_view_get_visible_offset (text_view, NULL, &lines->visible_offset);
 
 	/* No need to calculate special wrapping if wrap mode is none */
 	if (gtk_text_view_get_wrap_mode (text_view) == GTK_WRAP_NONE)
@@ -249,6 +260,11 @@ _gtk_source_gutter_lines_new (GtkTextView       *text_view,
 			quark_set_add (&info.classes, q_cursor_line);
 		}
 
+		if G_UNLIKELY (i >= first_selected && i <= last_selected)
+		{
+			quark_set_add (&info.classes, q_selected);
+		}
+
 		g_array_append_val (lines->lines, info);
 
 		if G_UNLIKELY (!gtk_text_iter_forward_line (&iter) &&
@@ -578,7 +594,7 @@ gtk_source_gutter_lines_get_buffer (GtkSourceGutterLines *lines)
 }
 
 /**
- * gtk_source_gutter_lines_get_line_yrange:
+ * gtk_source_gutter_lines_get_line_extent:
  * @lines: a #GtkSourceGutterLines
  * @line: a line number starting from zero
  * @mode: a #GtkSourceGutterRendererAlignmentMode
@@ -590,11 +606,11 @@ gtk_source_gutter_lines_get_buffer (GtkSourceGutterLines *lines)
  * The value for @y is relative to the renderers widget coordinates.
  */
 void
-gtk_source_gutter_lines_get_line_yrange (GtkSourceGutterLines                 *lines,
+gtk_source_gutter_lines_get_line_extent (GtkSourceGutterLines                 *lines,
                                          guint                                 line,
                                          GtkSourceGutterRendererAlignmentMode  mode,
-                                         gint                                 *y,
-                                         gint                                 *height)
+                                         double                               *y,
+                                         double                               *height)
 {
 	LineInfo *info;
 
@@ -624,7 +640,41 @@ gtk_source_gutter_lines_get_line_yrange (GtkSourceGutterLines                 *l
 		g_return_if_reached ();
 	}
 
-	*y -= lines->visible_rect.y;
+	*y -= lines->visible_offset;
+}
+
+/**
+ * gtk_source_gutter_lines_get_line_yrange:
+ * @lines: a #GtkSourceGutterLines
+ * @line: a line number starting from zero
+ * @mode: a #GtkSourceGutterRendererAlignmentMode
+ * @y: (out): a location for the Y position in widget coordinates
+ * @height: (out): the line height based on @mode
+ *
+ * Gets the Y range for a line based on @mode.
+ *
+ * The value for @y is relative to the renderers widget coordinates.
+ */
+void
+gtk_source_gutter_lines_get_line_yrange (GtkSourceGutterLines                 *lines,
+                                         guint                                 line,
+                                         GtkSourceGutterRendererAlignmentMode  mode,
+                                         gint                                 *y,
+                                         gint                                 *height)
+{
+	double d_y, d_height;
+
+	gtk_source_gutter_lines_get_line_extent (lines, line, mode, &d_y, &d_height);
+
+	if (y != NULL)
+	{
+		*y = floor (d_y);
+	}
+
+	if (height != NULL)
+	{
+		*height = ceil (d_height);
+	}
 }
 
 guint
@@ -634,3 +684,26 @@ _gtk_source_gutter_lines_get_cursor_line (GtkSourceGutterLines *lines)
 
 	return lines->cursor_line;
 }
+
+/**
+ * gtk_source_gutter_lines_has_any_class:
+ * @lines: a #GtkSourceGutterLines
+ * @line: a line contained within @lines
+ *
+ * Checks to see if the line has any GQuark classes set. This can be
+ * used to help renderer implementations avoid work if nothing has
+ * been set on the class.
+ *
+ * Returns: %TRUE if any quark was set for the line
+ *
+ * Since: 5.6
+ */
+gboolean
+gtk_source_gutter_lines_has_any_class (GtkSourceGutterLines *lines,
+                                       guint                 line)
+{
+	if (lines == NULL || line < lines->first || line > lines->last || line - lines->first >= lines->lines->len)
+    return FALSE;
+
+  return g_array_index (lines->lines, LineInfo, line - lines->first).classes.len > 0;
+}
