@@ -509,8 +509,7 @@ gtk_source_map_rebuild_css (GtkSourceMap *map)
 
 	if (gstr->len > 0)
 	{
-		/* use -1 to avoid a copy of the string */
-		gtk_css_provider_load_from_data (priv->css_provider, gstr->str, -1);
+		gtk_css_provider_load_from_string (priv->css_provider, gstr->str);
 	}
 
 	g_string_free (gstr, TRUE);
@@ -1427,6 +1426,7 @@ gtk_source_map_init (GtkSourceMap *map)
 	gtk_widget_add_controller (GTK_WIDGET (map), g_steal_pointer (&scroll));
 
 	press = GTK_EVENT_CONTROLLER (gtk_gesture_click_new ());
+	gtk_gesture_single_set_button (GTK_GESTURE_SINGLE (press), 0);
 	g_signal_connect_swapped (press,
 	                          "pressed",
 	                          G_CALLBACK (gtk_source_map_click_pressed),
