@@ -24,6 +24,7 @@
 #include "gtksourcebuffer-private.h"
 #include "gtksourcelanguage.h"
 #include "gtksourcesnippet-private.h"
+#include "gtksourcesnippetbundle-private.h"
 #include "gtksourcesnippetchunk-private.h"
 #include "gtksourcesnippetcontext-private.h"
 
@@ -210,12 +211,18 @@ GtkSourceSnippetChunk *
 gtk_source_snippet_get_nth_chunk (GtkSourceSnippet *snippet,
                                   guint             nth)
 {
+	GtkSourceSnippetChunk *chunk = NULL;
+
 	g_return_val_if_fail (GTK_SOURCE_IS_SNIPPET (snippet), 0);
 
 	if (nth < snippet->chunks.length)
-		return g_queue_peek_nth (&snippet->chunks, nth);
+	{
+		chunk = g_queue_peek_nth (&snippet->chunks, nth);
+	}
 
-	return NULL;
+	g_return_val_if_fail (!chunk || GTK_SOURCE_IS_SNIPPET_CHUNK (chunk), NULL);
+
+	return chunk;
 }
 
 /**
@@ -849,11 +856,11 @@ gtk_source_snippet_add_chunk (GtkSourceSnippet      *snippet,
 	g_return_if_fail (GTK_SOURCE_IS_SNIPPET (snippet));
 	g_return_if_fail (GTK_SOURCE_IS_SNIPPET_CHUNK (chunk));
 	g_return_if_fail (!snippet->inserted);
-	g_return_if_fail (chunk->link.data != NULL);
+	g_return_if_fail (chunk->link.data == chunk);
 	g_return_if_fail (chunk->link.prev == NULL);
 	g_return_if_fail (chunk->link.next == NULL);
 
-	g_object_ref_sink (chunk);
+	g_object_ref (chunk);
 
 	g_queue_push_tail_link (&snippet->chunks, &chunk->link);
 
@@ -1413,3 +1420,54 @@ _gtk_source_snippet_replace_current_chunk_text (GtkSourceSnippet *snippet,
 		gtk_source_snippet_chunk_set_text_set (snippet->current_chunk, TRUE);
 	}
 }
+
+/**
+ * gtk_source_snippet_new_parsed:
+ * @text: the formatted snippet text to parse
+ * @error: a location for a #GError or %NULL
+ *
+ * Parses the snippet formatted @text into a series of chunks and adds them
+ * to a new #GtkSourceSnippet.
+ *
+ * Returns: (transfer full): the newly parsed #GtkSourceSnippet, or %NULL upon
+ *   failure and @error is set.
+ *
+ * Since: 5.6
+ */
+GtkSourceSnippet *
+gtk_source_snippet_new_parsed (const char  *text,
+                               GError     **error)
+{
+	GtkSourceSnippet *snippet;
+	GPtrArray *chunks;
+
+	g_return_val_if_fail (text != NULL, NULL);
+
+	chunks = _gtk_source_snippet_bundle_parse_text (text, error);
+
+	if (chunks == NULL)
+	{
+		return NULL;
+	}
+
+	if (chunks->len == 0)
+	{
+		g_set_error (error,
+			     G_IO_ERROR,
+			     G_IO_ERROR_INVALID_DATA,
+			     "Failed to parse any content from snippet text");
+		g_ptr_array_unref (chunks);
+		return NULL;
+	}
+
+	snippet = gtk_source_snippet_new (NULL, NULL);
+
+	for (guint i = 0; i < chunks->len; i++)
+	{
+		gtk_source_snippet_add_chunk (snippet, g_ptr_array_index (chunks, i));
+	}
+
+	g_ptr_array_unref (chunks);
+
+	return g_steal_pointer (&snippet);
+}
