@@ -61,5 +61,36 @@ G_GNUC_INTERNAL
 void     _gtk_source_utils_aligned_free                  (gpointer                     data);
 G_GNUC_INTERNAL
 gsize    _gtk_source_utils_get_page_size                 (void) G_GNUC_CONST;
+G_GNUC_INTERNAL
+PangoFontMap *_gtk_source_utils_get_builder_blocks       (void);
+G_GNUC_INTERNAL
+gsize    _gtk_source_utils_strnlen                       (const char                  *str,
+                                                          gsize                        maxlen);
+
+static inline void
+premix_colors (GdkRGBA       *dest,
+               const GdkRGBA *fg,
+               const GdkRGBA *bg,
+               gboolean       bg_set,
+               double         alpha)
+{
+	g_assert (dest != NULL);
+	g_assert (fg != NULL);
+	g_assert (bg != NULL || bg_set == FALSE);
+	g_assert (alpha >= 0.0 && alpha <= 1.0);
+
+	if (bg_set)
+	{
+		dest->red = ((1 - alpha) * bg->red) + (alpha * fg->red);
+		dest->green = ((1 - alpha) * bg->green) + (alpha * fg->green);
+		dest->blue = ((1 - alpha) * bg->blue) + (alpha * fg->blue);
+		dest->alpha = 1.0;
+	}
+	else
+	{
+		*dest = *fg;
+		dest->alpha = alpha;
+	}
+}
 
 G_END_DECLS
