@@ -129,7 +129,7 @@ _gtk_source_view_assistants_hide_all (GtkSourceViewAssistants *assistants)
 
 		if (gtk_widget_get_visible (GTK_WIDGET (assistant)))
 		{
-			gtk_widget_hide (GTK_WIDGET (assistant));
+			gtk_widget_set_visible (GTK_WIDGET (assistant), FALSE);
 			ret = TRUE;
 		}
 	}
